@@ -1,10 +1,7 @@
 package Template::Liquid::Context;
 { $Template::Liquid::Context::VERSION = 'v1.0.0' }
-use strict;
-use warnings;
-use lib '../';
-use Template::Liquid::Utility;
-use Template::Liquid::Error;
+require Template::Liquid::Utility;
+require Template::Liquid::Error;
 sub scopes    { return $_[0]->{'scopes'} }
 sub scope     { return $_[0]->{'scopes'}->[-1] }
 sub filters   { return $_[0]->{'filters'} }
@@ -93,7 +90,7 @@ sub __merge {    # unless right is more interesting, this is a left-
     };
     for my $key (keys %{$_[0]}) {
         my ($left_ref, $right_ref)
-            = map { ref($_->{$key}) =~ m[^(HASH|ARRAY)$] ? $1 : 'SCALAR' }
+            = map { ref($_->{$key}) =~ m[^(HASH|ARRAY)$]o ? $1 : 'SCALAR' }
             ($_[0], $_[1]);
 
         #warn sprintf '%-12s [%6s|%-6s]', $key, $left_ref, $right_ref;
@@ -115,9 +112,9 @@ sub resolve {
     return !!1 if $path eq 'true';
     return $2 if $path =~ m[^(['"])(.+)\1$];
     return [int $s->resolve($1) .. int $s->resolve($2)]
-        if $path =~ m[^\((\S+)\.\.(\S+)\)$];    # range
-    return $1 if $path =~ m[^(\d+(?:[\d\.]+)?)$];    # int or bad float
-    return $s->resolve($1)->[$2] if $path =~ m'^(.+)\[(.+)\]$';
+        if $path =~ m[^\((\S+)\.\.(\S+)\)$]o;    # range
+    return $1 if $path =~ m[^(\d+(?:[\d\.]+)?)$]o;    # int or bad float
+    return $s->resolve($1)->[$2] if $path =~ m'^(.+)\[(.+)\]$'o;
     my @path = split $Template::Liquid::Utility::VariableAttributeSeparator,
         $path;
     my $cursor = \$s->scope;
@@ -130,7 +127,7 @@ sub resolve {
                 return scalar $$cursor->[0]  if $path->[0] eq 'first';
                 return scalar $$cursor->[-1] if $path->[0] eq 'last';
             }
-            return unless /^(?:0|[0-9]\d*)\z/;
+            return unless /^(?:0|[0-9]\d*)\z/o;
             if (scalar @path) { $cursor = \$$cursor->[$_]; next; }
             return defined $val ?
                 $$cursor->[$_]
