@@ -1,9 +1,6 @@
 package Template::Liquid::Variable;
 { $Template::Liquid::Variable::VERSION = 'v1.0.0' }
-use strict;
-use warnings;
-use lib '../../lib';
-use Template::Liquid::Error;
+require Template::Liquid::Error;
 our @ISA = qw[Template::Liquid::Document];
 
 sub new {
@@ -29,11 +26,11 @@ sub new {
 
 sub render {
     my ($s) = @_;
-    my $val = $s->resolve($s->{'variable'});
+    my $val = $s->{template}{context}->resolve($s->{'variable'});
 FILTER: for my $filter (@{$s->{'filters'}}) {
         my ($name, $args) = @$filter;
-        map { $_ = $s->resolve($_) || $_ } @$args;
-    PACKAGE: for my $package (@{$s->template->filters}) {
+        map { $_ = $s->{template}{context}->resolve($_) || $_ } @$args;
+    PACKAGE: for my $package (@{$s->{template}{filters}}) {
             if (my $call = $package->can($name)) {
                 $val = $call->($val, @$args);
                 next FILTER;
